@@ -3,10 +3,12 @@ The FreshBooks Python SDK allows you to more easily utilize the [FreshBooks API]
 
 - See `freshbooks.client.Client` for instantiating a Client, auth, and resource calls
 - See `freshbooks.api.accounting` and `freshbooks.api.projects` for resource methods (`get`, `list`, `create`, etc.)
-- See `freshbooks.builders` for list filters, pagination, etc.
+- See `freshbooks.builders` for list filters, pagination, includes, etc.
+- See `freshbooks.models` for Result objects, lists, identities, and vis state objects.
 """
 
 from freshbooks.builders.filter import FilterBuilder  # noqa
+from freshbooks.builders.includes import IncludesBuilder  # noqa
 from freshbooks.builders.paginator import PaginateBuilder  # noqa
 from freshbooks.client import Client  # noqa
 from freshbooks.errors import FreshBooksError  # noqa
